# Proactive Tracker

> Track proactive behaviors and their outcomes.

## Active Behaviors

| Behavior | Last Triggered | Status |
|----------|---------------|--------|
| — | — | — |

## Ideas Queue

> Things to build/do proactively

## Completed

> Log completed proactive actions here
